@@ -2,10 +2,11 @@
 Logging configuration
 """
 import logging
-import os
 import sys
 import traceback
 
+from hypertrace.env_var_settings import get_env_value
+
 _LOG_LEVEL = {
     None: logging.INFO,
     '': logging.INFO,
@@ -26,9 +27,9 @@ def get_custom_logger(name: str) -> logging.Logger:
         screen_handler.setFormatter(formatter)
         log_level = logging.INFO
         logger_ = logging.getLogger(name)
-        if 'HT_LOG_LEVEL' in os.environ:
-            ht_log_level = os.environ['HT_LOG_LEVEL']
-            log_level = _LOG_LEVEL.get(ht_log_level, log_level)
+        env_value = get_env_value('LOG_LEVEL')
+        if env_value:
+            log_level = _LOG_LEVEL.get(env_value, log_level)
 
         logger_.setLevel(log_level)
         logger_.addHandler(screen_handler)
